/* This file is part of the KDE project
   Copyright (C) 2001-2004 Ian Geiser <geiseri@kde.org>
   Copyright (C) 2002-2004 Nadeem Hasan <nhasan@kde.org>
   Copyright (C) 2003-2004 John Ratke

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _WEATHER_SERVICE
#define _WEATHER_SERVICE

#include <qstringlist.h>
#include <dcopobject.h>
#include <qpixmap.h>

class WeatherLib;
class StationDatabase;

class WeatherService : virtual public QObject, virtual public DCOPObject
{
	Q_OBJECT
	K_DCOP

	private:
		WeatherLib  *m_weatherLib;

	private slots:
		virtual void updated(QString stationID);
		virtual void updating(QString stationID);
		virtual void slotStationRemoved(QString stationID);

	public:
		WeatherService(QObject *parent, const char *name);
		virtual ~WeatherService();

	k_dcop_signals:
		virtual void fileUpdating(QString stationID);
		virtual void fileUpdate(QString stationID);
		virtual void stationRemoved(QString stationID);

	k_dcop:
		virtual QString temperature(const QString &stationID);
		virtual QString dewPoint(const QString &stationID);
		virtual QString relativeHumidity(const QString &stationID);
		virtual QString heatIndex(const QString &stationID);
		virtual QString windChill(const QString &stationID);
		virtual QString wind(const QString &stationID);
		virtual QString pressure(const QString &stationID);
		virtual QPixmap currentIcon(const QString &stationID);
		virtual QPixmap icon(const QString &stationID);
		virtual QString currentIconString(const QString &stationID);
		virtual QString iconFileName(const QString &stationID);
		virtual QString date(const QString &stationID);
		virtual QString visibility(const QString &stationID);
		virtual QStringList cover(const QString &stationID);
		virtual QStringList weather(const QString &stationID);
		virtual bool stationNeedsMaintenance(const QString &stationID);

		virtual QString stationName(const QString &stationID);
		virtual QString stationCountry(const QString &stationID);
		virtual QString longitude(const QString &stationID);
		virtual QString latitude(const QString &stationID);

		virtual QStringList findStations(float lon, float lat);

		virtual QString sunRiseTime(const QString &stationID);
		virtual QString sunSetTime(const QString &stationID);
		virtual QString civilTwilightStart(const QString &stationID);
		virtual QString civilTwilightEnd(const QString &stationID);

		virtual void update(QString stationID);
		virtual void updateAll();
		virtual void forceUpdate(QString stationID);
		virtual void removeStation(QString stationID);
		virtual void addStation(QString stationID);
		virtual QStringList listStations();
		virtual QString stationCode( const QString &stationName );
		
		virtual void exit();

  private:
		enum TimeType
		{
			RISE = 0,
			SET,
			CIVIL_START,
			CIVIL_END
		};
	  
		virtual void saveSettings();
		virtual QString getTime(const QString &stationID, TimeType timeType);
		StationDatabase *stationDB;
};
#endif
